INavigation2D_tests {#master}
-----------

Important Changes
-----------------

### Libraries

#### `harness_dev`
* Navigation2DClientTest.cpp refactored
* Added tests for `Navigation2DClient -> Navigation2DServer` communication
* Added tests for `Navigation2D_nwc_yarp -> Navigation2D_nws_yarp` communication

